@@ -24,7 +24,7 @@ impl<T> CholeskyDec<T>
 impl<T> CholeskyDec<T>
 {
     /// Return the l matrix
-    pub fn l(self: Self) -> Matrix<T>
+    pub fn l(self) -> Matrix<T>
     {
         self.l
     }
